# district42 experimental types

[![Codecov](https://img.shields.io/codecov/c/github/nikitanovosibirsk/district42-exp-types/master.svg?style=flat-square)](https://codecov.io/gh/nikitanovosibirsk/district42-exp-types)
[![PyPI](https://img.shields.io/pypi/v/district42-exp-types.svg?style=flat-square)](https://pypi.python.org/pypi/district42-exp-types/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/district42-exp-types?style=flat-square)](https://pypi.python.org/pypi/district42-exp-types/)
[![Python Version](https://img.shields.io/pypi/pyversions/district42-exp-types.svg?style=flat-square)](https://pypi.python.org/pypi/district42-exp-types/)

## Installation

```sh
pip3 install district42-exp-types
```
